//
//  SCAdSequencingController.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "SCAdListener.h"
#import "SCAdSequencingDelegate.h"

@class SCAdVariants;
@class SCAdContentView;
/**
 Controls the sequence and starting points of multiple videos played
 by SCAdController. This controller is not automatically started
 after initialization.
 */
@interface SCAdSequencingController : NSObject <SCAdListener>

/// Set this if you want to get informed about the state of internal SCAdController that this sequencer uses. Usually not needed.
@property (nonatomic, weak) id<SCAdListener> sdkDelegate;

/// This delegate needs to be implemented to synchronize your content player with this sequencer.
/// Provides the sequencer with information about the content player state and controls.
@property (nonatomic, weak) id<SCAdSequencingDelegate> sequencingDelegate;

/**
 Initializes SCAdSequencingController with a given sequence map and the anchor
 view to display the adverts sequence in.

 - Parameter sequenceMap: key value map where the key is position of ad and the value is the url of the ad clip to play
 - Parameter anchor: the container view to display the videos in
 */
- (id)initWithParentViewController:(UIViewController*)parentViewController sequenceMap:(NSDictionary*)sequenceMap anchor:(SCAdContentView*)anchor;

/// returns if this sequence controller is currently running an advertisment clip or not
- (BOOL)isAdRunning;

/// Current advert played by this controller can be resumed with this method. Has no effect if there is no advert running currently.
- (void)playCurrentAdvert;

/// Current advert can be paused with this method. Has no effect if there is no advert running currently.
- (void)pauseCurrentAdvert;

/**
 Starts this sequencers udpdate method. From this moment on ad urls from the
 sequence map will be processed and shown if content player has reached a position
 of an ad from sequence map.
 */
- (void)start;

/**
 Pause the sequencer manually. Note: You need to call this method when you started the
 sequencer before and don't want to use it anymore. E.g. when you leaving the parent
 view controller. Otherwise sequencer will continue to update itself and therefor cannot
 deallocate.
 */
- (void)pause;
@end
